# FlightPrice Package
O pacote Flight Price e uma ferramenta que permite buscar os melhores precos de voos por meio de web scraping em diferentes sites de companhias areas e agencias de viagens. Com este pacote, voce pode automatizar a busca por precos competitivos para suas viagens.

Instalacao
Para instalar o pacote Flight Price, voce pode usar o pip. Abra um terminal e execute o seguinte comando: pip install  FlightPrice

Uso
import FlightPrice

#utilizando a biblioteca.
scraper = Bucador_voos('Sao paulo','Rio de janeiro','17/01/2024','17/02/2024')
voos = scraper.melhores_precos

#Exibindo informacoes dos voos.
for c,k in var.items():
    print(var[c])


Contribuicao
Contribuicoes sao bem-vindas! Se você quiser melhorar o pacote Flight Price, sinta-se a vontade para abrir uma pull request no repositorio do GitHub.


Aviso Legal
O pacote Flight Price foi desenvolvido apenas para fins educacionais e de demonstracao. O web scraping pode violar os termos de servico de alguns sites. Certifique-se de estar em conformidade com as politicas de uso dos sites que voce deseja fazer scraping.

Licenca
Este projeto e licenciado sob a Licenca MIT - consulte o arquivo LICENSE para obter mais detalhes.